# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/server.proto',
  package='Server',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15protobuf/server.proto\x12\x06Server\"\xc2\x03\n\rServerCommand\x12\x0c\n\x04UUID\x18\x01 \x01(\t\x12\x15\n\x0blog_message\x18\x02 \x01(\tH\x00\x12\x18\n\x0e\x63\x61pture_screen\x18\x03 \x01(\x08H\x00\x12\x33\n\x12\x61\x64\x64_custom_control\x18\x04 \x01(\x0b\x32\x15.Server.CustomControlH\x00\x12\'\n\nset_camera\x18\x05 \x01(\x0b\x32\x11.Server.SetCameraH\x00\x12\'\n\nadd_object\x18\x06 \x01(\x0b\x32\x11.Server.AddObjectH\x00\x12;\n\x15set_key_event_handler\x18\x07 \x01(\x0b\x32\x1a.Server.SetKeyEventHandlerH\x00\x12-\n\rremove_object\x18\x08 \x01(\x0b\x32\x14.Server.RemoveObjectH\x00\x12<\n\x15remove_custom_control\x18\t \x01(\x0b\x32\x1b.Server.RemoveCustomControlH\x00\x12\x36\n\x12set_custom_control\x18\n \x01(\x0b\x32\x18.Server.SetCustomControlH\x00\x42\t\n\x07\x43ommand\"\xbf\x06\n\rCustomControl\x12.\n\x06slider\x18\x01 \x01(\x0b\x32\x1c.Server.CustomControl.SliderH\x00\x12\x32\n\x08\x63heckbox\x18\x02 \x01(\x0b\x32\x1e.Server.CustomControl.CheckBoxH\x00\x12\x30\n\x07textbox\x18\x03 \x01(\x0b\x32\x1d.Server.CustomControl.TextBoxH\x00\x12\x34\n\tselectbox\x18\x04 \x01(\x0b\x32\x1f.Server.CustomControl.SelectBoxH\x00\x12.\n\x06\x62utton\x18\x05 \x01(\x0b\x32\x1c.Server.CustomControl.ButtonH\x00\x12\x39\n\x0c\x63olor_picker\x18\x06 \x01(\x0b\x32!.Server.CustomControl.ColorPickerH\x00\x12.\n\x06\x66older\x18\x07 \x01(\x0b\x32\x1c.Server.CustomControl.FolderH\x00\x1a\x62\n\x06Slider\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03min\x18\x02 \x01(\x02\x12\x0b\n\x03max\x18\x03 \x01(\x02\x12\x0c\n\x04step\x18\x04 \x01(\x02\x12\x12\n\ninit_value\x18\x05 \x01(\x02\x12\x0e\n\x06parent\x18\x06 \x01(\t\x1a<\n\x08\x43heckBox\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninit_value\x18\x02 \x01(\x08\x12\x0e\n\x06parent\x18\x03 \x01(\t\x1a;\n\x07TextBox\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninit_value\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x1aL\n\tSelectBox\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05items\x18\x02 \x03(\t\x12\x12\n\ninit_value\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x1a&\n\x06\x42utton\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\t\x1a?\n\x0b\x43olorPicker\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninit_value\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x1a&\n\x06\x46older\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\tB\t\n\x07\x43ontrol\"A\n\x13RemoveCustomControl\x12\r\n\x03\x61ll\x18\x01 \x01(\x08H\x00\x12\x11\n\x07\x62y_uuid\x18\x02 \x01(\tH\x00\x42\x08\n\x06Object\"\x9f\x01\n\tSetCamera\x12\x19\n\x0fperspective_fov\x18\x01 \x01(\x02H\x00\x12%\n\x1borthographic_frustum_height\x18\x02 \x01(\x02H\x00\x12#\n\x08position\x18\x03 \x01(\x0b\x32\x0f.Server.VecXYZfH\x00\x12!\n\x06target\x18\x04 \x01(\x0b\x32\x0f.Server.VecXYZfH\x00\x42\x08\n\x06\x43\x61mera\"\xb4\x06\n\tAddObject\x12-\n\x08line_set\x18\x01 \x01(\x0b\x32\x19.Server.AddObject.LineSetH\x00\x12\x33\n\x0bpoint_cloud\x18\x02 \x01(\x0b\x32\x1c.Server.AddObject.PointCloudH\x00\x12,\n\x07overlay\x18\x03 \x01(\x0b\x32\x19.Server.AddObject.OverlayH\x00\x12&\n\x04mesh\x18\x04 \x01(\x0b\x32\x16.Server.AddObject.MeshH\x00\x1a\x81\x01\n\x07LineSet\x12\x1f\n\x06points\x18\x01 \x03(\x0b\x32\x0f.Server.VecXYZf\x12\x12\n\nfrom_index\x18\x02 \x03(\x05\x12\x10\n\x08to_index\x18\x03 \x03(\x05\x12\x1f\n\x06\x63olors\x18\x04 \x03(\x0b\x32\x0f.Server.VecRGBf\x12\x0e\n\x06widths\x18\x05 \x03(\x02\x1a\x32\n\nPointCloud\x12\x10\n\x08pcd_data\x18\x01 \x01(\x0c\x12\x12\n\npoint_size\x18\x02 \x01(\x02\x1a\x97\x02\n\x07Overlay\x12!\n\x08position\x18\x01 \x01(\x0b\x32\x0f.Server.VecXYZf\x12\x0e\n\x04html\x18\x02 \x01(\tH\x00\x12\x30\n\x05image\x18\x03 \x01(\x0b\x32\x1f.Server.AddObject.Overlay.ImageH\x00\x12\x36\n\x04type\x18\x04 \x01(\x0e\x32(.Server.AddObject.Overlay.CoordinateType\x1a$\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05width\x18\x02 \x01(\x05\"=\n\x0e\x43oordinateType\x12\x14\n\x10WORLD_COORDINATE\x10\x00\x12\x15\n\x11SCREEN_COORDINATE\x10\x01\x42\n\n\x08\x43ontents\x1a\x90\x01\n\x04Mesh\x12\x1f\n\x06points\x18\x01 \x03(\x0b\x32\x0f.Server.VecXYZf\x12\x16\n\x0evertex_a_index\x18\x02 \x03(\x05\x12\x16\n\x0evertex_b_index\x18\x03 \x03(\x05\x12\x16\n\x0evertex_c_index\x18\x04 \x03(\x05\x12\x1f\n\x06\x63olors\x18\x05 \x03(\x0b\x32\x0f.Server.VecRGBfB\x08\n\x06Object\":\n\x0cRemoveObject\x12\r\n\x03\x61ll\x18\x01 \x01(\x08H\x00\x12\x11\n\x07\x62y_uuid\x18\x02 \x01(\tH\x00\x42\x08\n\x06Object\"U\n\x12SetKeyEventHandler\x12\x11\n\x07keydown\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05keyup\x18\x02 \x01(\x08H\x00\x12\x12\n\x08keypress\x18\x03 \x01(\x08H\x00\x42\x07\n\x05\x45vent\"*\n\x07VecXYZf\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"*\n\x07VecRGBf\x12\t\n\x01r\x18\x01 \x01(\x02\x12\t\n\x01g\x18\x02 \x01(\x02\x12\t\n\x01\x62\x18\x03 \x01(\x02\"\xdb\x06\n\x10SetCustomControl\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x31\n\x06slider\x18\x02 \x01(\x0b\x32\x1f.Server.SetCustomControl.SliderH\x00\x12\x35\n\x08\x63heckbox\x18\x03 \x01(\x0b\x32!.Server.SetCustomControl.CheckBoxH\x00\x12\x33\n\x07textbox\x18\x04 \x01(\x0b\x32 .Server.SetCustomControl.TextBoxH\x00\x12\x37\n\tselectbox\x18\x05 \x01(\x0b\x32\".Server.SetCustomControl.SelectBoxH\x00\x12\x31\n\x06\x62utton\x18\x06 \x01(\x0b\x32\x1f.Server.SetCustomControl.ButtonH\x00\x12<\n\x0c\x63olor_picker\x18\x07 \x01(\x0b\x32$.Server.SetCustomControl.ColorPickerH\x00\x1a\x92\x01\n\x06Slider\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03min\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x10\n\x03max\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x12\n\x05value\x18\x05 \x01(\x02H\x04\x88\x01\x01\x42\x07\n\x05_nameB\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_stepB\x08\n\x06_value\x1a\x44\n\x08\x43heckBox\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\x1a\x43\n\x07TextBox\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\x1aT\n\tSelectBox\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\r\n\x05items\x18\x02 \x03(\t\x12\x12\n\x05value\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\x1a$\n\x06\x42utton\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\x1aG\n\x0b\x43olorPicker\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_valueB\t\n\x07\x43ontrolb\x06proto3'
)



_ADDOBJECT_OVERLAY_COORDINATETYPE = _descriptor.EnumDescriptor(
  name='CoordinateType',
  full_name='Server.AddObject.Overlay.CoordinateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORLD_COORDINATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCREEN_COORDINATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2140,
  serialized_end=2201,
)
_sym_db.RegisterEnumDescriptor(_ADDOBJECT_OVERLAY_COORDINATETYPE)


_SERVERCOMMAND = _descriptor.Descriptor(
  name='ServerCommand',
  full_name='Server.ServerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='UUID', full_name='Server.ServerCommand.UUID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_message', full_name='Server.ServerCommand.log_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capture_screen', full_name='Server.ServerCommand.capture_screen', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_custom_control', full_name='Server.ServerCommand.add_custom_control', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_camera', full_name='Server.ServerCommand.set_camera', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_object', full_name='Server.ServerCommand.add_object', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_key_event_handler', full_name='Server.ServerCommand.set_key_event_handler', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_object', full_name='Server.ServerCommand.remove_object', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_custom_control', full_name='Server.ServerCommand.remove_custom_control', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_custom_control', full_name='Server.ServerCommand.set_custom_control', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Command', full_name='Server.ServerCommand.Command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=34,
  serialized_end=484,
)


_CUSTOMCONTROL_SLIDER = _descriptor.Descriptor(
  name='Slider',
  full_name='Server.CustomControl.Slider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.CustomControl.Slider.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='Server.CustomControl.Slider.min', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='Server.CustomControl.Slider.max', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='Server.CustomControl.Slider.step', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_value', full_name='Server.CustomControl.Slider.init_value', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='Server.CustomControl.Slider.parent', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=961,
)

_CUSTOMCONTROL_CHECKBOX = _descriptor.Descriptor(
  name='CheckBox',
  full_name='Server.CustomControl.CheckBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.CustomControl.CheckBox.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_value', full_name='Server.CustomControl.CheckBox.init_value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='Server.CustomControl.CheckBox.parent', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1023,
)

_CUSTOMCONTROL_TEXTBOX = _descriptor.Descriptor(
  name='TextBox',
  full_name='Server.CustomControl.TextBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.CustomControl.TextBox.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_value', full_name='Server.CustomControl.TextBox.init_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='Server.CustomControl.TextBox.parent', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1084,
)

_CUSTOMCONTROL_SELECTBOX = _descriptor.Descriptor(
  name='SelectBox',
  full_name='Server.CustomControl.SelectBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.CustomControl.SelectBox.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Server.CustomControl.SelectBox.items', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_value', full_name='Server.CustomControl.SelectBox.init_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='Server.CustomControl.SelectBox.parent', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1162,
)

_CUSTOMCONTROL_BUTTON = _descriptor.Descriptor(
  name='Button',
  full_name='Server.CustomControl.Button',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.CustomControl.Button.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='Server.CustomControl.Button.parent', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1202,
)

_CUSTOMCONTROL_COLORPICKER = _descriptor.Descriptor(
  name='ColorPicker',
  full_name='Server.CustomControl.ColorPicker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.CustomControl.ColorPicker.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_value', full_name='Server.CustomControl.ColorPicker.init_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='Server.CustomControl.ColorPicker.parent', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1204,
  serialized_end=1267,
)

_CUSTOMCONTROL_FOLDER = _descriptor.Descriptor(
  name='Folder',
  full_name='Server.CustomControl.Folder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.CustomControl.Folder.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='Server.CustomControl.Folder.parent', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1307,
)

_CUSTOMCONTROL = _descriptor.Descriptor(
  name='CustomControl',
  full_name='Server.CustomControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slider', full_name='Server.CustomControl.slider', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkbox', full_name='Server.CustomControl.checkbox', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textbox', full_name='Server.CustomControl.textbox', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectbox', full_name='Server.CustomControl.selectbox', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='Server.CustomControl.button', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_picker', full_name='Server.CustomControl.color_picker', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder', full_name='Server.CustomControl.folder', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CUSTOMCONTROL_SLIDER, _CUSTOMCONTROL_CHECKBOX, _CUSTOMCONTROL_TEXTBOX, _CUSTOMCONTROL_SELECTBOX, _CUSTOMCONTROL_BUTTON, _CUSTOMCONTROL_COLORPICKER, _CUSTOMCONTROL_FOLDER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Control', full_name='Server.CustomControl.Control',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=487,
  serialized_end=1318,
)


_REMOVECUSTOMCONTROL = _descriptor.Descriptor(
  name='RemoveCustomControl',
  full_name='Server.RemoveCustomControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all', full_name='Server.RemoveCustomControl.all', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='by_uuid', full_name='Server.RemoveCustomControl.by_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Object', full_name='Server.RemoveCustomControl.Object',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1320,
  serialized_end=1385,
)


_SETCAMERA = _descriptor.Descriptor(
  name='SetCamera',
  full_name='Server.SetCamera',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective_fov', full_name='Server.SetCamera.perspective_fov', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orthographic_frustum_height', full_name='Server.SetCamera.orthographic_frustum_height', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='Server.SetCamera.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='Server.SetCamera.target', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Camera', full_name='Server.SetCamera.Camera',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1388,
  serialized_end=1547,
)


_ADDOBJECT_LINESET = _descriptor.Descriptor(
  name='LineSet',
  full_name='Server.AddObject.LineSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='Server.AddObject.LineSet.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_index', full_name='Server.AddObject.LineSet.from_index', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_index', full_name='Server.AddObject.LineSet.to_index', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='colors', full_name='Server.AddObject.LineSet.colors', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='widths', full_name='Server.AddObject.LineSet.widths', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1879,
)

_ADDOBJECT_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='Server.AddObject.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pcd_data', full_name='Server.AddObject.PointCloud.pcd_data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_size', full_name='Server.AddObject.PointCloud.point_size', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1881,
  serialized_end=1931,
)

_ADDOBJECT_OVERLAY_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='Server.AddObject.Overlay.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Server.AddObject.Overlay.Image.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='Server.AddObject.Overlay.Image.width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2102,
  serialized_end=2138,
)

_ADDOBJECT_OVERLAY = _descriptor.Descriptor(
  name='Overlay',
  full_name='Server.AddObject.Overlay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='Server.AddObject.Overlay.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='html', full_name='Server.AddObject.Overlay.html', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='Server.AddObject.Overlay.image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Server.AddObject.Overlay.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADDOBJECT_OVERLAY_IMAGE, ],
  enum_types=[
    _ADDOBJECT_OVERLAY_COORDINATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Contents', full_name='Server.AddObject.Overlay.Contents',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1934,
  serialized_end=2213,
)

_ADDOBJECT_MESH = _descriptor.Descriptor(
  name='Mesh',
  full_name='Server.AddObject.Mesh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='Server.AddObject.Mesh.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertex_a_index', full_name='Server.AddObject.Mesh.vertex_a_index', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertex_b_index', full_name='Server.AddObject.Mesh.vertex_b_index', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertex_c_index', full_name='Server.AddObject.Mesh.vertex_c_index', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='colors', full_name='Server.AddObject.Mesh.colors', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2216,
  serialized_end=2360,
)

_ADDOBJECT = _descriptor.Descriptor(
  name='AddObject',
  full_name='Server.AddObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_set', full_name='Server.AddObject.line_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='Server.AddObject.point_cloud', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlay', full_name='Server.AddObject.overlay', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mesh', full_name='Server.AddObject.mesh', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADDOBJECT_LINESET, _ADDOBJECT_POINTCLOUD, _ADDOBJECT_OVERLAY, _ADDOBJECT_MESH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Object', full_name='Server.AddObject.Object',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1550,
  serialized_end=2370,
)


_REMOVEOBJECT = _descriptor.Descriptor(
  name='RemoveObject',
  full_name='Server.RemoveObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all', full_name='Server.RemoveObject.all', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='by_uuid', full_name='Server.RemoveObject.by_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Object', full_name='Server.RemoveObject.Object',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2372,
  serialized_end=2430,
)


_SETKEYEVENTHANDLER = _descriptor.Descriptor(
  name='SetKeyEventHandler',
  full_name='Server.SetKeyEventHandler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keydown', full_name='Server.SetKeyEventHandler.keydown', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyup', full_name='Server.SetKeyEventHandler.keyup', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keypress', full_name='Server.SetKeyEventHandler.keypress', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='Server.SetKeyEventHandler.Event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2432,
  serialized_end=2517,
)


_VECXYZF = _descriptor.Descriptor(
  name='VecXYZf',
  full_name='Server.VecXYZf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='Server.VecXYZf.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='Server.VecXYZf.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='Server.VecXYZf.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2519,
  serialized_end=2561,
)


_VECRGBF = _descriptor.Descriptor(
  name='VecRGBf',
  full_name='Server.VecRGBf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='Server.VecRGBf.r', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='Server.VecRGBf.g', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='Server.VecRGBf.b', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2563,
  serialized_end=2605,
)


_SETCUSTOMCONTROL_SLIDER = _descriptor.Descriptor(
  name='Slider',
  full_name='Server.SetCustomControl.Slider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.SetCustomControl.Slider.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='Server.SetCustomControl.Slider.min', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='Server.SetCustomControl.Slider.max', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='Server.SetCustomControl.Slider.step', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Server.SetCustomControl.Slider.value', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='Server.SetCustomControl.Slider._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_min', full_name='Server.SetCustomControl.Slider._min',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max', full_name='Server.SetCustomControl.Slider._max',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='Server.SetCustomControl.Slider._step',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='Server.SetCustomControl.Slider._value',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2974,
  serialized_end=3120,
)

_SETCUSTOMCONTROL_CHECKBOX = _descriptor.Descriptor(
  name='CheckBox',
  full_name='Server.SetCustomControl.CheckBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.SetCustomControl.CheckBox.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Server.SetCustomControl.CheckBox.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='Server.SetCustomControl.CheckBox._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='Server.SetCustomControl.CheckBox._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3122,
  serialized_end=3190,
)

_SETCUSTOMCONTROL_TEXTBOX = _descriptor.Descriptor(
  name='TextBox',
  full_name='Server.SetCustomControl.TextBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.SetCustomControl.TextBox.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Server.SetCustomControl.TextBox.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='Server.SetCustomControl.TextBox._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='Server.SetCustomControl.TextBox._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3192,
  serialized_end=3259,
)

_SETCUSTOMCONTROL_SELECTBOX = _descriptor.Descriptor(
  name='SelectBox',
  full_name='Server.SetCustomControl.SelectBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.SetCustomControl.SelectBox.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Server.SetCustomControl.SelectBox.items', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Server.SetCustomControl.SelectBox.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='Server.SetCustomControl.SelectBox._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='Server.SetCustomControl.SelectBox._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3261,
  serialized_end=3345,
)

_SETCUSTOMCONTROL_BUTTON = _descriptor.Descriptor(
  name='Button',
  full_name='Server.SetCustomControl.Button',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.SetCustomControl.Button.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='Server.SetCustomControl.Button._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3347,
  serialized_end=3383,
)

_SETCUSTOMCONTROL_COLORPICKER = _descriptor.Descriptor(
  name='ColorPicker',
  full_name='Server.SetCustomControl.ColorPicker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Server.SetCustomControl.ColorPicker.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Server.SetCustomControl.ColorPicker.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='Server.SetCustomControl.ColorPicker._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='Server.SetCustomControl.ColorPicker._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3385,
  serialized_end=3456,
)

_SETCUSTOMCONTROL = _descriptor.Descriptor(
  name='SetCustomControl',
  full_name='Server.SetCustomControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Server.SetCustomControl.target', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slider', full_name='Server.SetCustomControl.slider', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkbox', full_name='Server.SetCustomControl.checkbox', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textbox', full_name='Server.SetCustomControl.textbox', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectbox', full_name='Server.SetCustomControl.selectbox', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='Server.SetCustomControl.button', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_picker', full_name='Server.SetCustomControl.color_picker', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SETCUSTOMCONTROL_SLIDER, _SETCUSTOMCONTROL_CHECKBOX, _SETCUSTOMCONTROL_TEXTBOX, _SETCUSTOMCONTROL_SELECTBOX, _SETCUSTOMCONTROL_BUTTON, _SETCUSTOMCONTROL_COLORPICKER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Control', full_name='Server.SetCustomControl.Control',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2608,
  serialized_end=3467,
)

_SERVERCOMMAND.fields_by_name['add_custom_control'].message_type = _CUSTOMCONTROL
_SERVERCOMMAND.fields_by_name['set_camera'].message_type = _SETCAMERA
_SERVERCOMMAND.fields_by_name['add_object'].message_type = _ADDOBJECT
_SERVERCOMMAND.fields_by_name['set_key_event_handler'].message_type = _SETKEYEVENTHANDLER
_SERVERCOMMAND.fields_by_name['remove_object'].message_type = _REMOVEOBJECT
_SERVERCOMMAND.fields_by_name['remove_custom_control'].message_type = _REMOVECUSTOMCONTROL
_SERVERCOMMAND.fields_by_name['set_custom_control'].message_type = _SETCUSTOMCONTROL
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['log_message'])
_SERVERCOMMAND.fields_by_name['log_message'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['capture_screen'])
_SERVERCOMMAND.fields_by_name['capture_screen'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['add_custom_control'])
_SERVERCOMMAND.fields_by_name['add_custom_control'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['set_camera'])
_SERVERCOMMAND.fields_by_name['set_camera'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['add_object'])
_SERVERCOMMAND.fields_by_name['add_object'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['set_key_event_handler'])
_SERVERCOMMAND.fields_by_name['set_key_event_handler'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['remove_object'])
_SERVERCOMMAND.fields_by_name['remove_object'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['remove_custom_control'])
_SERVERCOMMAND.fields_by_name['remove_custom_control'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_SERVERCOMMAND.oneofs_by_name['Command'].fields.append(
  _SERVERCOMMAND.fields_by_name['set_custom_control'])
_SERVERCOMMAND.fields_by_name['set_custom_control'].containing_oneof = _SERVERCOMMAND.oneofs_by_name['Command']
_CUSTOMCONTROL_SLIDER.containing_type = _CUSTOMCONTROL
_CUSTOMCONTROL_CHECKBOX.containing_type = _CUSTOMCONTROL
_CUSTOMCONTROL_TEXTBOX.containing_type = _CUSTOMCONTROL
_CUSTOMCONTROL_SELECTBOX.containing_type = _CUSTOMCONTROL
_CUSTOMCONTROL_BUTTON.containing_type = _CUSTOMCONTROL
_CUSTOMCONTROL_COLORPICKER.containing_type = _CUSTOMCONTROL
_CUSTOMCONTROL_FOLDER.containing_type = _CUSTOMCONTROL
_CUSTOMCONTROL.fields_by_name['slider'].message_type = _CUSTOMCONTROL_SLIDER
_CUSTOMCONTROL.fields_by_name['checkbox'].message_type = _CUSTOMCONTROL_CHECKBOX
_CUSTOMCONTROL.fields_by_name['textbox'].message_type = _CUSTOMCONTROL_TEXTBOX
_CUSTOMCONTROL.fields_by_name['selectbox'].message_type = _CUSTOMCONTROL_SELECTBOX
_CUSTOMCONTROL.fields_by_name['button'].message_type = _CUSTOMCONTROL_BUTTON
_CUSTOMCONTROL.fields_by_name['color_picker'].message_type = _CUSTOMCONTROL_COLORPICKER
_CUSTOMCONTROL.fields_by_name['folder'].message_type = _CUSTOMCONTROL_FOLDER
_CUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _CUSTOMCONTROL.fields_by_name['slider'])
_CUSTOMCONTROL.fields_by_name['slider'].containing_oneof = _CUSTOMCONTROL.oneofs_by_name['Control']
_CUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _CUSTOMCONTROL.fields_by_name['checkbox'])
_CUSTOMCONTROL.fields_by_name['checkbox'].containing_oneof = _CUSTOMCONTROL.oneofs_by_name['Control']
_CUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _CUSTOMCONTROL.fields_by_name['textbox'])
_CUSTOMCONTROL.fields_by_name['textbox'].containing_oneof = _CUSTOMCONTROL.oneofs_by_name['Control']
_CUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _CUSTOMCONTROL.fields_by_name['selectbox'])
_CUSTOMCONTROL.fields_by_name['selectbox'].containing_oneof = _CUSTOMCONTROL.oneofs_by_name['Control']
_CUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _CUSTOMCONTROL.fields_by_name['button'])
_CUSTOMCONTROL.fields_by_name['button'].containing_oneof = _CUSTOMCONTROL.oneofs_by_name['Control']
_CUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _CUSTOMCONTROL.fields_by_name['color_picker'])
_CUSTOMCONTROL.fields_by_name['color_picker'].containing_oneof = _CUSTOMCONTROL.oneofs_by_name['Control']
_CUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _CUSTOMCONTROL.fields_by_name['folder'])
_CUSTOMCONTROL.fields_by_name['folder'].containing_oneof = _CUSTOMCONTROL.oneofs_by_name['Control']
_REMOVECUSTOMCONTROL.oneofs_by_name['Object'].fields.append(
  _REMOVECUSTOMCONTROL.fields_by_name['all'])
_REMOVECUSTOMCONTROL.fields_by_name['all'].containing_oneof = _REMOVECUSTOMCONTROL.oneofs_by_name['Object']
_REMOVECUSTOMCONTROL.oneofs_by_name['Object'].fields.append(
  _REMOVECUSTOMCONTROL.fields_by_name['by_uuid'])
_REMOVECUSTOMCONTROL.fields_by_name['by_uuid'].containing_oneof = _REMOVECUSTOMCONTROL.oneofs_by_name['Object']
_SETCAMERA.fields_by_name['position'].message_type = _VECXYZF
_SETCAMERA.fields_by_name['target'].message_type = _VECXYZF
_SETCAMERA.oneofs_by_name['Camera'].fields.append(
  _SETCAMERA.fields_by_name['perspective_fov'])
_SETCAMERA.fields_by_name['perspective_fov'].containing_oneof = _SETCAMERA.oneofs_by_name['Camera']
_SETCAMERA.oneofs_by_name['Camera'].fields.append(
  _SETCAMERA.fields_by_name['orthographic_frustum_height'])
_SETCAMERA.fields_by_name['orthographic_frustum_height'].containing_oneof = _SETCAMERA.oneofs_by_name['Camera']
_SETCAMERA.oneofs_by_name['Camera'].fields.append(
  _SETCAMERA.fields_by_name['position'])
_SETCAMERA.fields_by_name['position'].containing_oneof = _SETCAMERA.oneofs_by_name['Camera']
_SETCAMERA.oneofs_by_name['Camera'].fields.append(
  _SETCAMERA.fields_by_name['target'])
_SETCAMERA.fields_by_name['target'].containing_oneof = _SETCAMERA.oneofs_by_name['Camera']
_ADDOBJECT_LINESET.fields_by_name['points'].message_type = _VECXYZF
_ADDOBJECT_LINESET.fields_by_name['colors'].message_type = _VECRGBF
_ADDOBJECT_LINESET.containing_type = _ADDOBJECT
_ADDOBJECT_POINTCLOUD.containing_type = _ADDOBJECT
_ADDOBJECT_OVERLAY_IMAGE.containing_type = _ADDOBJECT_OVERLAY
_ADDOBJECT_OVERLAY.fields_by_name['position'].message_type = _VECXYZF
_ADDOBJECT_OVERLAY.fields_by_name['image'].message_type = _ADDOBJECT_OVERLAY_IMAGE
_ADDOBJECT_OVERLAY.fields_by_name['type'].enum_type = _ADDOBJECT_OVERLAY_COORDINATETYPE
_ADDOBJECT_OVERLAY.containing_type = _ADDOBJECT
_ADDOBJECT_OVERLAY_COORDINATETYPE.containing_type = _ADDOBJECT_OVERLAY
_ADDOBJECT_OVERLAY.oneofs_by_name['Contents'].fields.append(
  _ADDOBJECT_OVERLAY.fields_by_name['html'])
_ADDOBJECT_OVERLAY.fields_by_name['html'].containing_oneof = _ADDOBJECT_OVERLAY.oneofs_by_name['Contents']
_ADDOBJECT_OVERLAY.oneofs_by_name['Contents'].fields.append(
  _ADDOBJECT_OVERLAY.fields_by_name['image'])
_ADDOBJECT_OVERLAY.fields_by_name['image'].containing_oneof = _ADDOBJECT_OVERLAY.oneofs_by_name['Contents']
_ADDOBJECT_MESH.fields_by_name['points'].message_type = _VECXYZF
_ADDOBJECT_MESH.fields_by_name['colors'].message_type = _VECRGBF
_ADDOBJECT_MESH.containing_type = _ADDOBJECT
_ADDOBJECT.fields_by_name['line_set'].message_type = _ADDOBJECT_LINESET
_ADDOBJECT.fields_by_name['point_cloud'].message_type = _ADDOBJECT_POINTCLOUD
_ADDOBJECT.fields_by_name['overlay'].message_type = _ADDOBJECT_OVERLAY
_ADDOBJECT.fields_by_name['mesh'].message_type = _ADDOBJECT_MESH
_ADDOBJECT.oneofs_by_name['Object'].fields.append(
  _ADDOBJECT.fields_by_name['line_set'])
_ADDOBJECT.fields_by_name['line_set'].containing_oneof = _ADDOBJECT.oneofs_by_name['Object']
_ADDOBJECT.oneofs_by_name['Object'].fields.append(
  _ADDOBJECT.fields_by_name['point_cloud'])
_ADDOBJECT.fields_by_name['point_cloud'].containing_oneof = _ADDOBJECT.oneofs_by_name['Object']
_ADDOBJECT.oneofs_by_name['Object'].fields.append(
  _ADDOBJECT.fields_by_name['overlay'])
_ADDOBJECT.fields_by_name['overlay'].containing_oneof = _ADDOBJECT.oneofs_by_name['Object']
_ADDOBJECT.oneofs_by_name['Object'].fields.append(
  _ADDOBJECT.fields_by_name['mesh'])
_ADDOBJECT.fields_by_name['mesh'].containing_oneof = _ADDOBJECT.oneofs_by_name['Object']
_REMOVEOBJECT.oneofs_by_name['Object'].fields.append(
  _REMOVEOBJECT.fields_by_name['all'])
_REMOVEOBJECT.fields_by_name['all'].containing_oneof = _REMOVEOBJECT.oneofs_by_name['Object']
_REMOVEOBJECT.oneofs_by_name['Object'].fields.append(
  _REMOVEOBJECT.fields_by_name['by_uuid'])
_REMOVEOBJECT.fields_by_name['by_uuid'].containing_oneof = _REMOVEOBJECT.oneofs_by_name['Object']
_SETKEYEVENTHANDLER.oneofs_by_name['Event'].fields.append(
  _SETKEYEVENTHANDLER.fields_by_name['keydown'])
_SETKEYEVENTHANDLER.fields_by_name['keydown'].containing_oneof = _SETKEYEVENTHANDLER.oneofs_by_name['Event']
_SETKEYEVENTHANDLER.oneofs_by_name['Event'].fields.append(
  _SETKEYEVENTHANDLER.fields_by_name['keyup'])
_SETKEYEVENTHANDLER.fields_by_name['keyup'].containing_oneof = _SETKEYEVENTHANDLER.oneofs_by_name['Event']
_SETKEYEVENTHANDLER.oneofs_by_name['Event'].fields.append(
  _SETKEYEVENTHANDLER.fields_by_name['keypress'])
_SETKEYEVENTHANDLER.fields_by_name['keypress'].containing_oneof = _SETKEYEVENTHANDLER.oneofs_by_name['Event']
_SETCUSTOMCONTROL_SLIDER.containing_type = _SETCUSTOMCONTROL
_SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_name'].fields.append(
  _SETCUSTOMCONTROL_SLIDER.fields_by_name['name'])
_SETCUSTOMCONTROL_SLIDER.fields_by_name['name'].containing_oneof = _SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_name']
_SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_min'].fields.append(
  _SETCUSTOMCONTROL_SLIDER.fields_by_name['min'])
_SETCUSTOMCONTROL_SLIDER.fields_by_name['min'].containing_oneof = _SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_min']
_SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_max'].fields.append(
  _SETCUSTOMCONTROL_SLIDER.fields_by_name['max'])
_SETCUSTOMCONTROL_SLIDER.fields_by_name['max'].containing_oneof = _SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_max']
_SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_step'].fields.append(
  _SETCUSTOMCONTROL_SLIDER.fields_by_name['step'])
_SETCUSTOMCONTROL_SLIDER.fields_by_name['step'].containing_oneof = _SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_step']
_SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_value'].fields.append(
  _SETCUSTOMCONTROL_SLIDER.fields_by_name['value'])
_SETCUSTOMCONTROL_SLIDER.fields_by_name['value'].containing_oneof = _SETCUSTOMCONTROL_SLIDER.oneofs_by_name['_value']
_SETCUSTOMCONTROL_CHECKBOX.containing_type = _SETCUSTOMCONTROL
_SETCUSTOMCONTROL_CHECKBOX.oneofs_by_name['_name'].fields.append(
  _SETCUSTOMCONTROL_CHECKBOX.fields_by_name['name'])
_SETCUSTOMCONTROL_CHECKBOX.fields_by_name['name'].containing_oneof = _SETCUSTOMCONTROL_CHECKBOX.oneofs_by_name['_name']
_SETCUSTOMCONTROL_CHECKBOX.oneofs_by_name['_value'].fields.append(
  _SETCUSTOMCONTROL_CHECKBOX.fields_by_name['value'])
_SETCUSTOMCONTROL_CHECKBOX.fields_by_name['value'].containing_oneof = _SETCUSTOMCONTROL_CHECKBOX.oneofs_by_name['_value']
_SETCUSTOMCONTROL_TEXTBOX.containing_type = _SETCUSTOMCONTROL
_SETCUSTOMCONTROL_TEXTBOX.oneofs_by_name['_name'].fields.append(
  _SETCUSTOMCONTROL_TEXTBOX.fields_by_name['name'])
_SETCUSTOMCONTROL_TEXTBOX.fields_by_name['name'].containing_oneof = _SETCUSTOMCONTROL_TEXTBOX.oneofs_by_name['_name']
_SETCUSTOMCONTROL_TEXTBOX.oneofs_by_name['_value'].fields.append(
  _SETCUSTOMCONTROL_TEXTBOX.fields_by_name['value'])
_SETCUSTOMCONTROL_TEXTBOX.fields_by_name['value'].containing_oneof = _SETCUSTOMCONTROL_TEXTBOX.oneofs_by_name['_value']
_SETCUSTOMCONTROL_SELECTBOX.containing_type = _SETCUSTOMCONTROL
_SETCUSTOMCONTROL_SELECTBOX.oneofs_by_name['_name'].fields.append(
  _SETCUSTOMCONTROL_SELECTBOX.fields_by_name['name'])
_SETCUSTOMCONTROL_SELECTBOX.fields_by_name['name'].containing_oneof = _SETCUSTOMCONTROL_SELECTBOX.oneofs_by_name['_name']
_SETCUSTOMCONTROL_SELECTBOX.oneofs_by_name['_value'].fields.append(
  _SETCUSTOMCONTROL_SELECTBOX.fields_by_name['value'])
_SETCUSTOMCONTROL_SELECTBOX.fields_by_name['value'].containing_oneof = _SETCUSTOMCONTROL_SELECTBOX.oneofs_by_name['_value']
_SETCUSTOMCONTROL_BUTTON.containing_type = _SETCUSTOMCONTROL
_SETCUSTOMCONTROL_BUTTON.oneofs_by_name['_name'].fields.append(
  _SETCUSTOMCONTROL_BUTTON.fields_by_name['name'])
_SETCUSTOMCONTROL_BUTTON.fields_by_name['name'].containing_oneof = _SETCUSTOMCONTROL_BUTTON.oneofs_by_name['_name']
_SETCUSTOMCONTROL_COLORPICKER.containing_type = _SETCUSTOMCONTROL
_SETCUSTOMCONTROL_COLORPICKER.oneofs_by_name['_name'].fields.append(
  _SETCUSTOMCONTROL_COLORPICKER.fields_by_name['name'])
_SETCUSTOMCONTROL_COLORPICKER.fields_by_name['name'].containing_oneof = _SETCUSTOMCONTROL_COLORPICKER.oneofs_by_name['_name']
_SETCUSTOMCONTROL_COLORPICKER.oneofs_by_name['_value'].fields.append(
  _SETCUSTOMCONTROL_COLORPICKER.fields_by_name['value'])
_SETCUSTOMCONTROL_COLORPICKER.fields_by_name['value'].containing_oneof = _SETCUSTOMCONTROL_COLORPICKER.oneofs_by_name['_value']
_SETCUSTOMCONTROL.fields_by_name['slider'].message_type = _SETCUSTOMCONTROL_SLIDER
_SETCUSTOMCONTROL.fields_by_name['checkbox'].message_type = _SETCUSTOMCONTROL_CHECKBOX
_SETCUSTOMCONTROL.fields_by_name['textbox'].message_type = _SETCUSTOMCONTROL_TEXTBOX
_SETCUSTOMCONTROL.fields_by_name['selectbox'].message_type = _SETCUSTOMCONTROL_SELECTBOX
_SETCUSTOMCONTROL.fields_by_name['button'].message_type = _SETCUSTOMCONTROL_BUTTON
_SETCUSTOMCONTROL.fields_by_name['color_picker'].message_type = _SETCUSTOMCONTROL_COLORPICKER
_SETCUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _SETCUSTOMCONTROL.fields_by_name['slider'])
_SETCUSTOMCONTROL.fields_by_name['slider'].containing_oneof = _SETCUSTOMCONTROL.oneofs_by_name['Control']
_SETCUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _SETCUSTOMCONTROL.fields_by_name['checkbox'])
_SETCUSTOMCONTROL.fields_by_name['checkbox'].containing_oneof = _SETCUSTOMCONTROL.oneofs_by_name['Control']
_SETCUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _SETCUSTOMCONTROL.fields_by_name['textbox'])
_SETCUSTOMCONTROL.fields_by_name['textbox'].containing_oneof = _SETCUSTOMCONTROL.oneofs_by_name['Control']
_SETCUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _SETCUSTOMCONTROL.fields_by_name['selectbox'])
_SETCUSTOMCONTROL.fields_by_name['selectbox'].containing_oneof = _SETCUSTOMCONTROL.oneofs_by_name['Control']
_SETCUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _SETCUSTOMCONTROL.fields_by_name['button'])
_SETCUSTOMCONTROL.fields_by_name['button'].containing_oneof = _SETCUSTOMCONTROL.oneofs_by_name['Control']
_SETCUSTOMCONTROL.oneofs_by_name['Control'].fields.append(
  _SETCUSTOMCONTROL.fields_by_name['color_picker'])
_SETCUSTOMCONTROL.fields_by_name['color_picker'].containing_oneof = _SETCUSTOMCONTROL.oneofs_by_name['Control']
DESCRIPTOR.message_types_by_name['ServerCommand'] = _SERVERCOMMAND
DESCRIPTOR.message_types_by_name['CustomControl'] = _CUSTOMCONTROL
DESCRIPTOR.message_types_by_name['RemoveCustomControl'] = _REMOVECUSTOMCONTROL
DESCRIPTOR.message_types_by_name['SetCamera'] = _SETCAMERA
DESCRIPTOR.message_types_by_name['AddObject'] = _ADDOBJECT
DESCRIPTOR.message_types_by_name['RemoveObject'] = _REMOVEOBJECT
DESCRIPTOR.message_types_by_name['SetKeyEventHandler'] = _SETKEYEVENTHANDLER
DESCRIPTOR.message_types_by_name['VecXYZf'] = _VECXYZF
DESCRIPTOR.message_types_by_name['VecRGBf'] = _VECRGBF
DESCRIPTOR.message_types_by_name['SetCustomControl'] = _SETCUSTOMCONTROL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServerCommand = _reflection.GeneratedProtocolMessageType('ServerCommand', (_message.Message,), {
  'DESCRIPTOR' : _SERVERCOMMAND,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.ServerCommand)
  })
_sym_db.RegisterMessage(ServerCommand)

CustomControl = _reflection.GeneratedProtocolMessageType('CustomControl', (_message.Message,), {

  'Slider' : _reflection.GeneratedProtocolMessageType('Slider', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMCONTROL_SLIDER,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.CustomControl.Slider)
    })
  ,

  'CheckBox' : _reflection.GeneratedProtocolMessageType('CheckBox', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMCONTROL_CHECKBOX,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.CustomControl.CheckBox)
    })
  ,

  'TextBox' : _reflection.GeneratedProtocolMessageType('TextBox', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMCONTROL_TEXTBOX,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.CustomControl.TextBox)
    })
  ,

  'SelectBox' : _reflection.GeneratedProtocolMessageType('SelectBox', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMCONTROL_SELECTBOX,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.CustomControl.SelectBox)
    })
  ,

  'Button' : _reflection.GeneratedProtocolMessageType('Button', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMCONTROL_BUTTON,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.CustomControl.Button)
    })
  ,

  'ColorPicker' : _reflection.GeneratedProtocolMessageType('ColorPicker', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMCONTROL_COLORPICKER,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.CustomControl.ColorPicker)
    })
  ,

  'Folder' : _reflection.GeneratedProtocolMessageType('Folder', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMCONTROL_FOLDER,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.CustomControl.Folder)
    })
  ,
  'DESCRIPTOR' : _CUSTOMCONTROL,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.CustomControl)
  })
_sym_db.RegisterMessage(CustomControl)
_sym_db.RegisterMessage(CustomControl.Slider)
_sym_db.RegisterMessage(CustomControl.CheckBox)
_sym_db.RegisterMessage(CustomControl.TextBox)
_sym_db.RegisterMessage(CustomControl.SelectBox)
_sym_db.RegisterMessage(CustomControl.Button)
_sym_db.RegisterMessage(CustomControl.ColorPicker)
_sym_db.RegisterMessage(CustomControl.Folder)

RemoveCustomControl = _reflection.GeneratedProtocolMessageType('RemoveCustomControl', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECUSTOMCONTROL,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.RemoveCustomControl)
  })
_sym_db.RegisterMessage(RemoveCustomControl)

SetCamera = _reflection.GeneratedProtocolMessageType('SetCamera', (_message.Message,), {
  'DESCRIPTOR' : _SETCAMERA,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.SetCamera)
  })
_sym_db.RegisterMessage(SetCamera)

AddObject = _reflection.GeneratedProtocolMessageType('AddObject', (_message.Message,), {

  'LineSet' : _reflection.GeneratedProtocolMessageType('LineSet', (_message.Message,), {
    'DESCRIPTOR' : _ADDOBJECT_LINESET,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.AddObject.LineSet)
    })
  ,

  'PointCloud' : _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), {
    'DESCRIPTOR' : _ADDOBJECT_POINTCLOUD,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.AddObject.PointCloud)
    })
  ,

  'Overlay' : _reflection.GeneratedProtocolMessageType('Overlay', (_message.Message,), {

    'Image' : _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
      'DESCRIPTOR' : _ADDOBJECT_OVERLAY_IMAGE,
      '__module__' : 'protobuf.server_pb2'
      # @@protoc_insertion_point(class_scope:Server.AddObject.Overlay.Image)
      })
    ,
    'DESCRIPTOR' : _ADDOBJECT_OVERLAY,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.AddObject.Overlay)
    })
  ,

  'Mesh' : _reflection.GeneratedProtocolMessageType('Mesh', (_message.Message,), {
    'DESCRIPTOR' : _ADDOBJECT_MESH,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.AddObject.Mesh)
    })
  ,
  'DESCRIPTOR' : _ADDOBJECT,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.AddObject)
  })
_sym_db.RegisterMessage(AddObject)
_sym_db.RegisterMessage(AddObject.LineSet)
_sym_db.RegisterMessage(AddObject.PointCloud)
_sym_db.RegisterMessage(AddObject.Overlay)
_sym_db.RegisterMessage(AddObject.Overlay.Image)
_sym_db.RegisterMessage(AddObject.Mesh)

RemoveObject = _reflection.GeneratedProtocolMessageType('RemoveObject', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOBJECT,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.RemoveObject)
  })
_sym_db.RegisterMessage(RemoveObject)

SetKeyEventHandler = _reflection.GeneratedProtocolMessageType('SetKeyEventHandler', (_message.Message,), {
  'DESCRIPTOR' : _SETKEYEVENTHANDLER,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.SetKeyEventHandler)
  })
_sym_db.RegisterMessage(SetKeyEventHandler)

VecXYZf = _reflection.GeneratedProtocolMessageType('VecXYZf', (_message.Message,), {
  'DESCRIPTOR' : _VECXYZF,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.VecXYZf)
  })
_sym_db.RegisterMessage(VecXYZf)

VecRGBf = _reflection.GeneratedProtocolMessageType('VecRGBf', (_message.Message,), {
  'DESCRIPTOR' : _VECRGBF,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.VecRGBf)
  })
_sym_db.RegisterMessage(VecRGBf)

SetCustomControl = _reflection.GeneratedProtocolMessageType('SetCustomControl', (_message.Message,), {

  'Slider' : _reflection.GeneratedProtocolMessageType('Slider', (_message.Message,), {
    'DESCRIPTOR' : _SETCUSTOMCONTROL_SLIDER,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.SetCustomControl.Slider)
    })
  ,

  'CheckBox' : _reflection.GeneratedProtocolMessageType('CheckBox', (_message.Message,), {
    'DESCRIPTOR' : _SETCUSTOMCONTROL_CHECKBOX,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.SetCustomControl.CheckBox)
    })
  ,

  'TextBox' : _reflection.GeneratedProtocolMessageType('TextBox', (_message.Message,), {
    'DESCRIPTOR' : _SETCUSTOMCONTROL_TEXTBOX,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.SetCustomControl.TextBox)
    })
  ,

  'SelectBox' : _reflection.GeneratedProtocolMessageType('SelectBox', (_message.Message,), {
    'DESCRIPTOR' : _SETCUSTOMCONTROL_SELECTBOX,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.SetCustomControl.SelectBox)
    })
  ,

  'Button' : _reflection.GeneratedProtocolMessageType('Button', (_message.Message,), {
    'DESCRIPTOR' : _SETCUSTOMCONTROL_BUTTON,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.SetCustomControl.Button)
    })
  ,

  'ColorPicker' : _reflection.GeneratedProtocolMessageType('ColorPicker', (_message.Message,), {
    'DESCRIPTOR' : _SETCUSTOMCONTROL_COLORPICKER,
    '__module__' : 'protobuf.server_pb2'
    # @@protoc_insertion_point(class_scope:Server.SetCustomControl.ColorPicker)
    })
  ,
  'DESCRIPTOR' : _SETCUSTOMCONTROL,
  '__module__' : 'protobuf.server_pb2'
  # @@protoc_insertion_point(class_scope:Server.SetCustomControl)
  })
_sym_db.RegisterMessage(SetCustomControl)
_sym_db.RegisterMessage(SetCustomControl.Slider)
_sym_db.RegisterMessage(SetCustomControl.CheckBox)
_sym_db.RegisterMessage(SetCustomControl.TextBox)
_sym_db.RegisterMessage(SetCustomControl.SelectBox)
_sym_db.RegisterMessage(SetCustomControl.Button)
_sym_db.RegisterMessage(SetCustomControl.ColorPicker)


# @@protoc_insertion_point(module_scope)
