# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/client.proto',
  package='Client',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15protobuf/client.proto\x12\x06\x43lient\"\xec\x01\n\rClientCommand\x12\x0c\n\x04UUID\x18\x01 \x01(\t\x12\x15\n\x0blog_message\x18\x02 \x01(\tH\x00\x12 \n\x06result\x18\x03 \x01(\x0b\x32\x0e.Client.ResultH\x00\x12\x1e\n\x05image\x18\x04 \x01(\x0b\x32\r.Client.ImageH\x00\x12\x31\n\x0f\x63ontrol_changed\x18\x05 \x01(\x0b\x32\x16.Client.ControlChangedH\x00\x12\x36\n\x12key_event_occurred\x18\x06 \x01(\x0b\x32\x18.Client.KeyEventOccurredH\x00\x42\t\n\x07\x43ommand\"8\n\x06Result\x12\x11\n\x07success\x18\x01 \x01(\tH\x00\x12\x11\n\x07\x66\x61ilure\x18\x02 \x01(\tH\x00\x42\x08\n\x06Result\"\x15\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"N\n\x0e\x43ontrolChanged\x12\x10\n\x06number\x18\x01 \x01(\x01H\x00\x12\x0e\n\x04text\x18\x02 \x01(\tH\x00\x12\x11\n\x07\x62oolean\x18\x03 \x01(\x08H\x00\x42\x07\n\x05Value\"\xb7\x02\n\x10KeyEventOccurred\x12\x32\n\x05keyup\x18\x01 \x01(\x0b\x32!.Client.KeyEventOccurred.KeyEventH\x00\x12\x34\n\x07keydown\x18\x02 \x01(\x0b\x32!.Client.KeyEventOccurred.KeyEventH\x00\x12\x35\n\x08keypress\x18\x03 \x01(\x0b\x32!.Client.KeyEventOccurred.KeyEventH\x00\x1ay\n\x08KeyEvent\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08shiftKey\x18\x03 \x01(\x08\x12\x0e\n\x06\x61ltKey\x18\x04 \x01(\x08\x12\x0f\n\x07\x63trlKey\x18\x05 \x01(\x08\x12\x0f\n\x07metaKey\x18\x06 \x01(\x08\x12\x0e\n\x06repeat\x18\x07 \x01(\x08\x42\x07\n\x05\x45ventb\x06proto3'
)




_CLIENTCOMMAND = _descriptor.Descriptor(
  name='ClientCommand',
  full_name='Client.ClientCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='UUID', full_name='Client.ClientCommand.UUID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_message', full_name='Client.ClientCommand.log_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='Client.ClientCommand.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='Client.ClientCommand.image', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_changed', full_name='Client.ClientCommand.control_changed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_event_occurred', full_name='Client.ClientCommand.key_event_occurred', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Command', full_name='Client.ClientCommand.Command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=34,
  serialized_end=270,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='Client.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='Client.Result.success', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure', full_name='Client.Result.failure', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Result', full_name='Client.Result.Result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=272,
  serialized_end=328,
)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='Client.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Client.Image.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=351,
)


_CONTROLCHANGED = _descriptor.Descriptor(
  name='ControlChanged',
  full_name='Client.ControlChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='Client.ControlChanged.number', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Client.ControlChanged.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boolean', full_name='Client.ControlChanged.boolean', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Value', full_name='Client.ControlChanged.Value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=353,
  serialized_end=431,
)


_KEYEVENTOCCURRED_KEYEVENT = _descriptor.Descriptor(
  name='KeyEvent',
  full_name='Client.KeyEventOccurred.KeyEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Client.KeyEventOccurred.KeyEvent.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Client.KeyEventOccurred.KeyEvent.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shiftKey', full_name='Client.KeyEventOccurred.KeyEvent.shiftKey', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altKey', full_name='Client.KeyEventOccurred.KeyEvent.altKey', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctrlKey', full_name='Client.KeyEventOccurred.KeyEvent.ctrlKey', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metaKey', full_name='Client.KeyEventOccurred.KeyEvent.metaKey', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='Client.KeyEventOccurred.KeyEvent.repeat', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=736,
)

_KEYEVENTOCCURRED = _descriptor.Descriptor(
  name='KeyEventOccurred',
  full_name='Client.KeyEventOccurred',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyup', full_name='Client.KeyEventOccurred.keyup', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keydown', full_name='Client.KeyEventOccurred.keydown', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keypress', full_name='Client.KeyEventOccurred.keypress', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_KEYEVENTOCCURRED_KEYEVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='Client.KeyEventOccurred.Event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=434,
  serialized_end=745,
)

_CLIENTCOMMAND.fields_by_name['result'].message_type = _RESULT
_CLIENTCOMMAND.fields_by_name['image'].message_type = _IMAGE
_CLIENTCOMMAND.fields_by_name['control_changed'].message_type = _CONTROLCHANGED
_CLIENTCOMMAND.fields_by_name['key_event_occurred'].message_type = _KEYEVENTOCCURRED
_CLIENTCOMMAND.oneofs_by_name['Command'].fields.append(
  _CLIENTCOMMAND.fields_by_name['log_message'])
_CLIENTCOMMAND.fields_by_name['log_message'].containing_oneof = _CLIENTCOMMAND.oneofs_by_name['Command']
_CLIENTCOMMAND.oneofs_by_name['Command'].fields.append(
  _CLIENTCOMMAND.fields_by_name['result'])
_CLIENTCOMMAND.fields_by_name['result'].containing_oneof = _CLIENTCOMMAND.oneofs_by_name['Command']
_CLIENTCOMMAND.oneofs_by_name['Command'].fields.append(
  _CLIENTCOMMAND.fields_by_name['image'])
_CLIENTCOMMAND.fields_by_name['image'].containing_oneof = _CLIENTCOMMAND.oneofs_by_name['Command']
_CLIENTCOMMAND.oneofs_by_name['Command'].fields.append(
  _CLIENTCOMMAND.fields_by_name['control_changed'])
_CLIENTCOMMAND.fields_by_name['control_changed'].containing_oneof = _CLIENTCOMMAND.oneofs_by_name['Command']
_CLIENTCOMMAND.oneofs_by_name['Command'].fields.append(
  _CLIENTCOMMAND.fields_by_name['key_event_occurred'])
_CLIENTCOMMAND.fields_by_name['key_event_occurred'].containing_oneof = _CLIENTCOMMAND.oneofs_by_name['Command']
_RESULT.oneofs_by_name['Result'].fields.append(
  _RESULT.fields_by_name['success'])
_RESULT.fields_by_name['success'].containing_oneof = _RESULT.oneofs_by_name['Result']
_RESULT.oneofs_by_name['Result'].fields.append(
  _RESULT.fields_by_name['failure'])
_RESULT.fields_by_name['failure'].containing_oneof = _RESULT.oneofs_by_name['Result']
_CONTROLCHANGED.oneofs_by_name['Value'].fields.append(
  _CONTROLCHANGED.fields_by_name['number'])
_CONTROLCHANGED.fields_by_name['number'].containing_oneof = _CONTROLCHANGED.oneofs_by_name['Value']
_CONTROLCHANGED.oneofs_by_name['Value'].fields.append(
  _CONTROLCHANGED.fields_by_name['text'])
_CONTROLCHANGED.fields_by_name['text'].containing_oneof = _CONTROLCHANGED.oneofs_by_name['Value']
_CONTROLCHANGED.oneofs_by_name['Value'].fields.append(
  _CONTROLCHANGED.fields_by_name['boolean'])
_CONTROLCHANGED.fields_by_name['boolean'].containing_oneof = _CONTROLCHANGED.oneofs_by_name['Value']
_KEYEVENTOCCURRED_KEYEVENT.containing_type = _KEYEVENTOCCURRED
_KEYEVENTOCCURRED.fields_by_name['keyup'].message_type = _KEYEVENTOCCURRED_KEYEVENT
_KEYEVENTOCCURRED.fields_by_name['keydown'].message_type = _KEYEVENTOCCURRED_KEYEVENT
_KEYEVENTOCCURRED.fields_by_name['keypress'].message_type = _KEYEVENTOCCURRED_KEYEVENT
_KEYEVENTOCCURRED.oneofs_by_name['Event'].fields.append(
  _KEYEVENTOCCURRED.fields_by_name['keyup'])
_KEYEVENTOCCURRED.fields_by_name['keyup'].containing_oneof = _KEYEVENTOCCURRED.oneofs_by_name['Event']
_KEYEVENTOCCURRED.oneofs_by_name['Event'].fields.append(
  _KEYEVENTOCCURRED.fields_by_name['keydown'])
_KEYEVENTOCCURRED.fields_by_name['keydown'].containing_oneof = _KEYEVENTOCCURRED.oneofs_by_name['Event']
_KEYEVENTOCCURRED.oneofs_by_name['Event'].fields.append(
  _KEYEVENTOCCURRED.fields_by_name['keypress'])
_KEYEVENTOCCURRED.fields_by_name['keypress'].containing_oneof = _KEYEVENTOCCURRED.oneofs_by_name['Event']
DESCRIPTOR.message_types_by_name['ClientCommand'] = _CLIENTCOMMAND
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['ControlChanged'] = _CONTROLCHANGED
DESCRIPTOR.message_types_by_name['KeyEventOccurred'] = _KEYEVENTOCCURRED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientCommand = _reflection.GeneratedProtocolMessageType('ClientCommand', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTCOMMAND,
  '__module__' : 'protobuf.client_pb2'
  # @@protoc_insertion_point(class_scope:Client.ClientCommand)
  })
_sym_db.RegisterMessage(ClientCommand)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'protobuf.client_pb2'
  # @@protoc_insertion_point(class_scope:Client.Result)
  })
_sym_db.RegisterMessage(Result)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'protobuf.client_pb2'
  # @@protoc_insertion_point(class_scope:Client.Image)
  })
_sym_db.RegisterMessage(Image)

ControlChanged = _reflection.GeneratedProtocolMessageType('ControlChanged', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLCHANGED,
  '__module__' : 'protobuf.client_pb2'
  # @@protoc_insertion_point(class_scope:Client.ControlChanged)
  })
_sym_db.RegisterMessage(ControlChanged)

KeyEventOccurred = _reflection.GeneratedProtocolMessageType('KeyEventOccurred', (_message.Message,), {

  'KeyEvent' : _reflection.GeneratedProtocolMessageType('KeyEvent', (_message.Message,), {
    'DESCRIPTOR' : _KEYEVENTOCCURRED_KEYEVENT,
    '__module__' : 'protobuf.client_pb2'
    # @@protoc_insertion_point(class_scope:Client.KeyEventOccurred.KeyEvent)
    })
  ,
  'DESCRIPTOR' : _KEYEVENTOCCURRED,
  '__module__' : 'protobuf.client_pb2'
  # @@protoc_insertion_point(class_scope:Client.KeyEventOccurred)
  })
_sym_db.RegisterMessage(KeyEventOccurred)
_sym_db.RegisterMessage(KeyEventOccurred.KeyEvent)


# @@protoc_insertion_point(module_scope)
