body {
    background-color: black;
    margin: 0;
}

.dg .property-name {
    cursor: default;
    float: left;
    clear: left;
    width: 40%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.cr.function .property-name {
    width: 100%;
}

/*# sourceMappingURL=main.css.map*/